@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_iam._jsii
@@ -16,7 +16,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-cognito", "1.63.0", __name__[0:-6], "aws-cognito@1.63.0.jsii.tgz"
+    "@aws-cdk/aws-cognito", "1.64.1", __name__[0:-6], "aws-cognito@1.64.1.jsii.tgz"
 )
 
 __all__ = [
